Struct InstallConfig

#[non_exhaustive]
pub struct InstallConfig { pub access_scope: AccessScope, pub destination: AppPathPrefix, pub source_dir: PathBuf, pub modify_os_search_path: bool, }
Parameters that control how the binary is installed.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
access_scope: AccessScope

Access scope.

destination: AppPathPrefix

Where the files will be installed.

source_dir: PathBuf

Where the files are coming from.

modify_os_search_path: bool

Whether to modify the search path (PATH).

On Windows, this will modify the environment variable and App Paths in the registry.

On Unix with user scope, this will modify the user’s shell profile config. The SHELL variable and the existence of the .bash_profile, .zprofile, or .profile will be used to select the appropriate file. If the file already contains the path, it will not be modified. For system scope, it’s not supported.

Implementations

Source

impl InstallConfig

pub fn new_user() -> Result<Self, InstallerError>

Create a new config suitable for a User install.

pub fn new_system() -> Result<Self, InstallerError>

Create a new config suitable for a System install.