Module path

Describing where files are located.

This module contains filesystem path abstractions and methods for translating them to real filesystem paths.

Default file locations

For binaries, they will be located in:

  • $HOME/.local/bin/
  • /usr/local/bin/
  • %LocalAppData%/Programs/[app-id]/bin/
  • %ProgramFiles%/[app-id]/bin/

[app-id] is the plain ID format.

For any data files:

  • $HOME/.local/share/[app-id]/
  • /usr/local/share/[app-id]/
  • %LocalAppData%/Programs/[app-id]/bin/
  • %ProgramFiles%/[app-id]/bin/

Structs

PathResolver
Resolves path abstractions into real file paths.

Enums

AppPathPrefix
Specifies abstractly where the files are installed on the machine.