pub struct PathResolver { /* private fields */ }Expand description
Resolves path abstractions into real file paths.
Implementations
Sourceimpl PathResolver
impl PathResolver
Sourcepub fn new<I: AsRef<str>>(
app_id: I,
prefix: &AppPathPrefix,
) -> Result<Self, InstallerError>
pub fn new<I: AsRef<str>>( app_id: I, prefix: &AppPathPrefix, ) -> Result<Self, InstallerError>
Create a new path resolver.
In order to match an existing installation, the exact arguments need to match when provided during installation.